@@ -9,12 +9,11 @@ class TodoBase(SQLModel):
     status: str = Field(default='todo')
     tags: str | None
     due_date: datetime | None
-    project_id: int | None
     project_id: Optional[int] = Field(default=None, foreign_key="project.id")
 
 
 class Todo(TodoBase, table=True):
-    id: int | None = Field(primary_key=True)
+    id: int | None = Field(default=None, primary_key=True)
     project: Optional['Project'] = Relationship(back_populates='todos')
 
 
@@ -31,7 +30,7 @@ class ProjectBase(SQLModel):
 
 
 class Project(ProjectBase, table=True):
-    id: int | None = Field(primary_key=True)
+    id: int | None = Field(default=None, primary_key=True)
     todos: Todo | None = Relationship(back_populates='project')
 
 
